<?php

  /*
  * Translate literal entities to their numeric equivalents and viceversa.
  *
  * PHP's XML parser (in V 4.1.0) has problems with entities! The onlyone's that are recognized
  * are &amp;, &lt; &gt; and &quot;. *ALL* others (like &nbsp; &copy;a.s.o.) cause an 
  * XML_ERROR_UNDEFINED_ENTITY error. I reported this as bug athttp://bugs.php.net/bug.php?id=15092
  * The work around is to translate the entities found in the XML sourceto their numeric equivalent
  * E.g. &nbsp; to &#160; / &copy; to &#169; a.s.o.
  * 
  * NOTE: Entities &amp;, &lt; &gt; and &quot; are left 'as is'
  * 
  * @author Sam Blum bs_php@users.sourceforge.net
  * @param string $xmlSource The XML string
  * @param bool   $reverse (default=FALSE) Translate numeric entities toliteral entities.
  * @return The XML string with translatet entities.
  */

  function _translateLiteral2NumericEntities($xmlSource, $reverse =FALSE) {
    static $literal2NumericEntity;
    
    if (empty($literal2NumericEntity)) {
      $transTbl = get_html_translation_table(HTML_ENTITIES);
      foreach ($transTbl as $char => $entity) {
        if (strpos('&"<>', $char) !== FALSE) continue;
        $literal2NumericEntity[$entity] = '&#'.ord($char).';';
      }
    }
    if ($reverse) {
      return strtr($xmlSource, array_flip($literal2NumericEntity));
    } else {
      return strtr($xmlSource, $literal2NumericEntity);
    }
  }

?>
