<?php
/***************************************************************************\
*   Name:           simpleturtle_template.php                               *
*                                                                           *
*                   Copyright 2002 Simple Turtle                            *
*                                                                           *
*   Date:           Apr 18, 2002                                            *
*                                                                           *
*   Author:         Elias  ( easfaw at simpleturtle.com )                   *
*                                                                           *
*   Purpose:        Will replace strings with other strings                 *
*                                                                           *
*   Use:            string = simpleturtle_template( path, my_list);         *
*                   string - will become the page that you echo/print out   *
*                   path - path to template (probably html) file            *
*                   my_list - Array that is indexed with the words to be    *
*                             replaced, and the contents are what will be   *
*                             replaced. If an element of an array is a      *
*                             two-dimensional (2D) array, it will be used   *
*                             to interpolate text in blocks.                *
*                                                                           *
*   Returns:        String - with the whole file if success full            *
*                   Null - if error, and SIMPLETURTLE_ERROR_TEXT will be set*
*                                                                           *
*   Example:        Array Looks like the following                          *
*     Array(                                                                *
*       'SERVER_NAME' => 'www.simpleturtle.com',                            *
*       'AUTHOR_NAME' => 'Eli',                                             *
*       'DYNAMICBLOCK' =>                                                   *
*           Array(                                                          *
*               0 => Array('COL1' => 'Column11', 'COL2' => 'Column12' ),    *
*               1 => Array('COL1' => 'Column21', 'COL2' => 'Column22' ),    *
*           ),                                                              *
*       '<!--LABEL2-->' => 'I am text'                                      *
*     );                                                                    *
*                                                                           *
*   History:                                                                *
*   User     Date     Description                                           *
*   -------- -------- ---------------------------------------------         *
*   elias    04/18/02 Started writing                                       *
*   elias    04/19/02 Finished debuggin 2D output errors                    *
*                                                                           *
\***************************************************************************/


function simpleturtle_template( $filepath, $subs ) {
    global $SIMPLETURTLE_ERROR_TEXT;
    $dynamicblocks = array();

    //
    // Open file and read in file
    if( file_exists($filepath) ) {
        $template = file( $filepath );
        $template_size = count( $template );
    } else {
        $SIMPLETURTLE_ERROR_TEXT =
          '<A HREF="http://www.simpleturtle.com">SIMPLETURTLE</A> ERROR: File '.
          $filepath . ' not found <BR>';
          return NULL;
    }

    //
    // If no array given
    if( $subs == NULL ) {
        $output = implode( NULL, $template );
        return $output;
    }

    //
    // Replace words with scalars from array for the whole template
    foreach( $subs as $label => $value ) {
        if( is_array($value) ) {
            continue;
        }

        // Replace every label with value for each line in the file
        foreach( $template as $number => $line ) {
            $template[$number] = str_replace( $label, $value, $line );
        }
    }
    
    
    
    //
    // Replace dynamic blocks with 2D arrays for the whole template
    foreach( $subs as $label => $value ) {
        if( !is_array($value) ) {
            continue;
        }

        // Find the start and end of lines of block we will replace
        $start = NULL;
        $end = NULL;
        for( $i = 0; $i < $template_size; $i++ ) {
            if( substr_count($template[$i], $label) > 0 ) { // Found on line
                if( $start != NULL && $end != NULL )
                    break;
                if( $start != NULL && $end == NULL )
                    $end = $i;
                if( $start == NULL )
                    $start = $i;
            }
        }

        // For each row in the 2D array
        foreach( $value as $itcount => $insidesubs ) {
            // For each line for that block
            for( $n = $start + 1; $n < $end; $n++ ) {
                $inline = $template[$n];
                
                // For every dynamic block sub
                foreach( $insidesubs as $inlabel => $invalue ) {
                    $inline = str_replace( $inlabel, $invalue, $inline );
                }
                $block .= $inline;
            }

        }; //

        $section = array( 'START' => $start, 'END' => $end, 'CONTENT' => $block );
        $dynamicblocks[] = $section;
        unset($block);
        $start = NULL;
        $end = NULL;

    }

    //
    // Lets create our output string and replace the dynamic blocks lines
    // with the data we collected in above loops
    for( $ln = 0; $ln < $template_size; $ln++ ) {
        $realline = $template[$ln];
        
        foreach( $dynamicblocks as $numblock => $dynblock ) {
            if( $ln >= $dynblock['START'] - 1 && $ln < $dynblock['END'] ) {
                $realline .= $dynblock['CONTENT'];
                $ln = $dynblock['END'];
            }
        }

        $output .= $realline;
    }
    
    //
    //
    return $output;
}

?>




